ParseError

Enum ParseError 

pub enum ParseError {
    Utf8(Utf8Error),
    TooLarge {
        len: usize,
        max: usize,
    },
}
Errors returned by fallible parsing APIs.

Soft syntax issues, such as missing separators, are not hard errors because crawlers are expected to recover from malformed robots.txt files where possible. Use RobotsTxt::parse_with_diagnostics or RobotsTxt::parse_bytes_with_diagnostics to collect those warnings.

Variants



Utf8(Utf8Error)

The input bytes were not valid UTF-8.



TooLarge

The input length exceeded ParseOptions::max_bytes.

Fields

len: usize

Actual input length in bytes.

max: usize

Configured maximum input length in bytes.