pub struct CrawlDelay<'a> {
pub agents: Vec<&'a str>,
pub value: &'a str,
}Available on crate feature
extensions only.Expand description
A Crawl-delay directive and the group agents active when it appeared.
Fields
agents: Vec<&'a str>Current group agents at the point where the directive appeared.
This is empty when Crawl-delay appears before any User-agent.
value: &'a strRaw Crawl-delay value.