pub struct Group<'a> {
pub agents: Vec<&'a str>,
pub rules: Vec<Rule<'a>>,
}Expand description
A robots.txt group containing one or more user agents and their rules.
Consecutive User-agent records before the first rule belong to the same
group. A later User-agent starts a new group after any Allow or
Disallow record has been seen.
Fields
agents: Vec<&'a str>User-agent product tokens covered by this group.
rules: Vec<Rule<'a>>Access-control rules associated with Group::agents.